@@ -46,7 +46,7 @@ GWAS(oi,
      file.path(dir,"example.pgen"),
      file.path(tdir, "out.log"), SNP=c(3:4,6))
 
-pgen <- loadResults(file.path(tdir, "out.log"))
+pgen <- loadResults(file.path(tdir, "out.log"), "snp2i1")
 rx <- which(min(pgen$P) == pgen$P)
 expect_equal(rx, 2)
 expect_equal(pgen$P[rx], 0.128, tolerance=1e-2)
@@ -64,7 +64,7 @@ GWAS(oi,
      file.path(dir,"example.pgen"),
      file.path(tdir, "out.log"), SNP=c(3:4,6))
 
-ml <- loadResults(file.path(tdir, "out.log"))
+ml <- loadResults(file.path(tdir, "out.log"), "snp2i1")
 expect_equal(cor(ml$P, pgen$P), 1, tolerance=1e-3)
 
 expect_error(buildOneItem(pheno, paste0("i", 1), fitfun = "bob"),
@@ -80,21 +80,18 @@ GWAS(buildOneFac(pheno, paste0("i", 1:numIndicators)),
      file.path(dir,"example.pgen"),
      file.path(tdir, "out.log"), SNP=c(3:4,6))
 
-pgen <- loadResults(file.path(tdir, "out.log"))
-pgen2 <- loadResults(rep(file.path(tdir, "out.log"), 2))
+pgen <- loadResults(file.path(tdir, "out.log"), "snp2F")
+pgen2 <- loadResults(rep(file.path(tdir, "out.log"), 2), 'snp2F')
 
 expect_equal(pgen$SNP, paste0("RSID_", c(4,5,7)))
 expect_equal(pgen2$SNP, rep(paste0("RSID_", c(4,5,7)), 2))
-expect_equal(pgen$snpReg, c(.2,.06, .02), tolerance=.02)
+expect_equal(pgen$snp2F, c(-.188, -.066, .006), tolerance=.001)
 
 pgen <- read.table(file.path(tdir, "out.log"), stringsAsFactors = FALSE, header=TRUE,
                    sep="\t", check.names=FALSE, quote="", comment.char="")
 
-expect_equivalent(pgen$i1_Thr_1, rep(quantile(origPheno$i1, 1/3),3), tolerance=.05)
-expect_equivalent(pgen$i1_Thr_2, rep(quantile(origPheno$i1, 2/3),3), tolerance=.12)
-expect_equivalent(pgen$i2_Thr_1, rep(0,3), tolerance=0.05)
 l2 <- pgen[,paste0('lambda_i',1:7)]
-expect_equivalent(colMeans(l2) / loadings, rep(1, numIndicators), tolerance=.25)
+expect_equivalent(colMeans(l2) / loadings, rep(1, numIndicators), tolerance=.2)
 
 if(0) {
   m1 <- buildOneFac(pheno, file.path(dir,"example.pgen"), paste0("i", 1:numIndicators), SNP=3)
@@ -110,15 +107,13 @@ GWAS(buildOneFacRes(pheno, paste0("i", 1:numIndicators)),
 pgen <- read.table(file.path(tdir, "out.log"), stringsAsFactors = FALSE, header=TRUE,
                    sep="\t", check.names=FALSE, quote="", comment.char="")
 expect_equivalent(pgen$i1_Thr_1, rep(quantile(origPheno$i1, 1/3),3), tolerance=.18)
-expect_equivalent(pgen$i1_Thr_2, rep(quantile(origPheno$i1, 2/3),3), tolerance=.15)
-expect_equivalent(pgen$i2_Thr_1, rep(0,3), tolerance=0.05)
+expect_equivalent(pgen$i2_Thr_1, rep(0,3), tolerance=0.15)
 
 l2 <- pgen[,paste0('lambda_i',1:7)]
-expect_equivalent(colMeans(l2) / loadings, rep(1, numIndicators), tolerance=.25)
+expect_equivalent(colMeans(l2) / loadings, rep(1, numIndicators), tolerance=.2)
 
 pgen <- loadResults(file.path(tdir, "out.log"), "snp2i2")
-rx <- which(min(pgen$P) == pgen$P)
-expect_equal(rx, 1)
+expect_equal(pgen$P, rep(1,3), tolerance=1e-5)
 
 # -----------------
 
@@ -129,12 +124,10 @@ GWAS(buildTwoFac(pheno, F1itemNames = paste0("i",1:4),
 
 pgen <- read.table(file.path(tdir, "out.log"), stringsAsFactors = FALSE, header=TRUE,
                    sep="\t", check.names=FALSE, quote="", comment.char="")
-expect_equivalent(pgen$i1_Thr_1, rep(quantile(origPheno$i1, 1/3),3), tolerance=.08)
-expect_equivalent(pgen$i1_Thr_2, rep(quantile(origPheno$i1, 2/3),3), tolerance=.15)
-expect_equivalent(pgen$i2_Thr_1, rep(0,3), tolerance=0.05)
 l2 <- pgen[,paste0('lambda_i',1:7)]
-expect_equivalent(colMeans(l2) / loadings, rep(1, numIndicators), tolerance=.25)
-expect_equal(pgen[['TwoFac.S[9,10]']], rep(1.17,3), .05)
+expect_equivalent((colMeans(l2) / loadings)[-4], rep(1, numIndicators-1),
+                  tolerance=.15)
+expect_equal(pgen[['TwoFac.S[9,10]']], rep(1.17,3), .02)
 
 # ------------
 
@@ -143,3 +136,4 @@ for (f in c("buildOneFac", "buildOneFacRes", "buildOneItem",
   expect_error(do.call(f, args=list(pheno, another.arg="xyz")),
                "Rejected are any values")
 }
+
